summaryrefslogtreecommitdiffstats
path: root/kmail/kmservertest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmservertest.cpp')
-rw-r--r--kmail/kmservertest.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/kmservertest.cpp b/kmail/kmservertest.cpp
index c184e6dfc..b99e1cc95 100644
--- a/kmail/kmservertest.cpp
+++ b/kmail/kmservertest.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -112,17 +112,17 @@ void KMServerTest::slotData(KIO::Job *, const TQString &data)
void KMServerTest::slotMetaData( const KIO::MetaData & md ) {
- KIO::MetaData::const_iterator it = md.find( "PLAIN AUTH METHODS" );
+ KIO::MetaData::const_iterator it = md.tqfind( "PLAIN AUTH METHODS" );
if ( it != md.end() ) {
mAuthNone = it.data();
kdDebug(5006) << "mAuthNone: " << mAuthNone << endl;
}
- it = md.find( "TLS AUTH METHODS" );
+ it = md.tqfind( "TLS AUTH METHODS" );
if ( it != md.end() ) {
mAuthTLS = it.data();
kdDebug(5006) << "mAuthTLS: " << mAuthTLS << endl;
}
- it = md.find( "SSL AUTH METHODS" );
+ it = md.tqfind( "SSL AUTH METHODS" );
if ( it != md.end() ) {
mAuthSSL = it.data();
kdDebug(5006) << "mAuthSSL: " << mAuthSSL << endl;
@@ -142,7 +142,7 @@ void KMServerTest::slotSlaveResult(KIO::Slave *aSlave, int error,
if (aSlave != mSlave) return;
if ( mSSL && error == 0 ) {
// add a dummy entry to the list of SSL capabilities so that the receiver
// of the capabilities signal can use mListSSL.isEmpty() in order to find
// out whether SSL is supported
mListSSL.append("SSL");
}
@@ -142,7 +142,7 @@ void KMServerTest::slotSlaveResult(KIO::Slave *aSlave, int error,
if ( mSSL && error == 0 ) {
// add a dummy entry to the list of SSL capabilities so that the receiver
- // of the capabilities signal can use mListSSL.isEmpty() in order to find
+ // of the capabilities signal can use mListSSL.isEmpty() in order to tqfind
// out whether SSL is supported
mListSSL.append("SSL");